@@ -27,7 +27,7 @@ role PDF::Outline
     has PDF::Outline $.First is entry(:indirect);      # (Required if the item has any descendants; must be an indirect reference) The first of this item’s immediate children in the outline hierarchy.
     has PDF::Outline $.Last is entry(:indirect);       # (Required if the item has any descendants; must be an indirect reference) The last of this item’s immediate children in the outline hierarchy.
     has Int $.Count is entry;                          # (Required if the item has any descendants) If the item is open, the total number of its open descendants at all lower levels of the outline hierarchy. If the item is closed, a negative integer whose absolute value specifies how many descendants would appear if the item were reopened.
-    has DestSpec $.Dest is entry(:coerce(&coerce-dest));              # (Optional; not permitted if an A entry is present) The destination to be displayed when this item is activated
+    has DestSpec $.Dest is entry(:alias<destination>, :coerce(&coerce-dest));              # (Optional; not permitted if an A entry is present) The destination to be displayed when this item is activated
     has PDF::Action $.A is entry(:alias<action>);      # (Optional; PDF 1.1; not permitted if a Dest entry is present) The action to be performed when this item is activated.
     has PDF::StructElem $.SE is entry(:indirect, :alias<structure-element>);                # (Optional; PDF 1.3; must be an indirect reference) The structure element to which the item refers.
     # Note: The ability to associate an outline item with a structure element (such as the beginning of a chapter) is a PDF 1.3 feature. For backward compatibility with earlier PDF versions, such an item should also specify a destination (Dest) corresponding to an area of a page where the contents of the designated structure element are displayed.
